Overview
========
This is an Infinidat project.

Usage
-----
Nothing to use here.

Checking out the code
=====================
Run the following commands:
    
    easy_install -U infi.projector
    projector devenv build

